import React, {Component, Fragment} from 'react'
import {Form, Select, Input, Switch, Radio, Slider, Button, DatePicker, Row, Col} from 'antd';
import './ItemTableQuery.scss'
const {Option} = Select;
const {RangePicker} = DatePicker;
class Tpl extends Component {
  constructor(props) {
    super(props);
  }
  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields((err, fieldsValue) => {
      if (err) {
        return
      }
      let values ={};
      if(fieldsValue.range_picker){
        const rangeValue = fieldsValue['range_picker'];
        values = {
          ...fieldsValue,
          'range_picker': [rangeValue[0].format('YYYY-MM-DD'), rangeValue[1].format('YYYY-MM-DD')],
        };
      }else {
        values = {
          ...fieldsValue,
        };
      }
      this.props.getTableQuery(values);
    });
  };

  handleReset = (e) => {
    this.props.form.resetFields();
    this.props.resetParams();
    this.handleSubmit(e)
  };
  render() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form layout="inline" onSubmit={this.handleSubmit}>
        {
          this.props.itemTableQuery.map((item, i) => {
            switch (item.type) {
              case 'range_picker':
                return (
                  <Form.Item label={item.label} key={i}>
                    {getFieldDecorator('range_picker',
                      {
                        initialValue:item.defaultSelectDate || null,
                        rules: [
                        {
                          type: 'array',
                          required: item.required||false,
                          message: '请选择时间!'
                        }],
                    })(
                      <RangePicker disabledDate={item.disabledDate||null}/>
                    )}
                  </Form.Item>
                );
              case 'input':
                return (
                  <Form.Item label={item.label} key={i}>
                    {getFieldDecorator(item.key, {
                      rules: [{
                        required: item.required,
                        message: item.placeholder,
                      }],
                    })(
                      <Input placeholder={item.placeholder} style={{minWidth:'260px'}}/>
                    )}
                  </Form.Item>
                );
              case 'select':
                return (
                  <Form.Item label={item.label} key={i}>
                    {getFieldDecorator(item.key, {
                      initialValue: item.defaultValue?item.defaultValue:undefined,
                      rules: [
                        {required: item.required, message: item.placeholder},
                      ],
                    })(
                      <Select onChange={item.onChange || null} disabled={item.disabled||false} placeholder={item.placeholder} style={{minWidth:'160px'}} allowClear mode={item.mode}>
                        {
                          item.data.map((item,index) => {
                            if(item)
                            return <Option value={item.id} key={index}>{item.name}</Option>
                          })
                        }
                      </Select>
                    )}
                  </Form.Item>
                );
              case 'radio':
                return (
                  <Form.Item label={item.label} key={i} {...this.formItemLayout}>
                    {getFieldDecorator(item.key, {
                      initialValue: this.props.dataSource[item.key]
                        ? this.props.dataSource[item.key]
                        : undefined,
                      rules: [
                        {
                          required: item.required,
                          message: "缺少" + item.label
                        }
                      ]
                    })(
                      <Radio.Group>
                        {item.data.map((data, index) => {
                          return <Radio value={data.id} key={index}>{data.name}</Radio>;
                        })}
                      </Radio.Group>
                    )}
                  </Form.Item>
                )
              case 'submit':
                return (
                  <Form.Item key={i} >
                  {
                    (()=> {
                      switch (item.extend) {
                        case true:
                          return item.render;
                        default: return <Fragment>
                          <Button type="primary" htmlType="submit" className="mr-20">查询</Button>
                          {/* <Button onClick={this.handleReset}>重置</Button> */}
                          {
                            (()=>{
                              if(item.render){
                                return item.render
                              }else {
                                return null
                              }
                            })()
                          }
                        </Fragment>
                      }
                    })()
                  }
                </Form.Item>
                )
            }
          })
        }
      </Form>
    )
  }
}

const ItemTableQuery = Form.create({name: 'form_query'})(Tpl);
export default ItemTableQuery;
